#
# spec file for package libgphoto2 (Version 2.4.9)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           libgphoto2
BuildRequires:  doxygen fdupes gcc-c++ gd-devel hal libexif-devel libjpeg-devel libusb-devel pkg-config udev
Url:            http://gphoto.org/
# bug437293
%ifarch ppc64
Obsoletes:      libgphoto2-64bit
%endif
#
%define prefix /usr
License:        LGPLv2.1+
Group:          Hardware/Camera
Summary:        A Digital Camera Library
Version:        2.4.9
Release:        1
Source0:        libgphoto2-%{version}.tar.bz2
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       %{name}-lang = %{version}

%package devel
Summary:        Development headers for libgphoto2
License:        LGPLv2.1+
Group:          Hardware/Camera
Requires:       libgphoto2 = %version libusb-devel
Requires:       libexif-devel

%description
gPhoto (GNU Photo) is a set of libraries for previewing, retrieving,
and capturing images from a range of supported digital cameras to your
local hard drive. It does not support digital cameras based on the USB
storage protocol. Those can be mounted by Linux directly.

As of this time, gPhoto supports around 1200 cameras, listed on:

http://gphoto.org/proj/libgphoto2/support.php

or by running

gphoto2 --list-cameras

%description devel
gPhoto (GNU Photo) is a set of libraries for previewing, retrieving,
and capturing images from a range of supported digital cameras to your
local hard drive.

These are its development libraries and headers.

%lang_package
%prep
%setup -q

%build
%{?suse_update_config:%{suse_update_config -f . libgphoto2_port}}
AUTOPOINT=true autoreconf -fi
PATH="/usr/X11R6/bin:$PATH"			\
%configure					\
  --with-doc-dir=%{_defaultdocdir}/%{name}	\
  --without-hal \
  --with-drivers=all
make %{?jobs:-j%jobs}

%check
make check

%install
# skip-check-libtool-deps
export LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}
%makeinstall
%{find_lang} libgphoto2-2
%{find_lang} libgphoto2_port-0
cat libgphoto2-2.lang libgphoto2_port-0.lang > libgphoto2-all.lang
pushd packaging/generic
	export CAMLIBS=$RPM_BUILD_ROOT/%_libdir/libgphoto2/%version/
	# Check the installed hal (in neededforbuild) if the directory
	# is still at the place we expect to avoid surprises.
	if [ ! -d /usr/share/hal/fdi/information/20thirdparty/ ] ; then
		echo "*** The hal FDI file location has changed. Fix the build."
		exit 1
	fi
	install -m 0755 -d            $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/
	./print-camera-list hal-fdi > $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/10-camera-libgphoto2.fdi
	# ./print-camera-list hal-fdi-dev > $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/10-camera-libgphoto2-device.fdi
	if [ ! -s $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/10-camera-libgphoto2.fdi ]; then
		echo "*** Did not generate a fdi map. Check the build."
		exit 1
	fi
%if 0%{?suse_version} >= 1120
	# new style UDEV rules (gudev) which will obsolete HAL fdi files
	if [ ! -d /lib/udev/rules.d/ ] ; then
		echo "*** The udev rules file location has changed. Fix the build."
		exit 1
	fi
	install -m 0755 -d                           $RPM_BUILD_ROOT/lib/udev/rules.d/
	./print-camera-list udev-rules version 136 > $RPM_BUILD_ROOT/lib/udev/rules.d/40-libgphoto2.rules
%endif
popd
# udev helpers not used here.
rm $RPM_BUILD_ROOT/usr/%_lib/udev/check-mtp-device
rm $RPM_BUILD_ROOT/usr/%_lib/udev/check-ptp-camera
mv doc/doxygen-output/libgphoto2-api.html apidocs 
fn=$RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libgphoto2_port.pc
grep -v driverdir= $fn > $fn.new
mv $fn.new $fn
# These two should not be required, but the driver .la can stay
rm $RPM_BUILD_ROOT/%{_libdir}/libgphoto2.la
rm $RPM_BUILD_ROOT/%{_libdir}/libgphoto2_port.la

%fdupes $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_libdir}/libgphoto2
%{_libdir}/libgphoto2_port
%dir %{_defaultdocdir}/%{name}
%exclude %{_defaultdocdir}/%{name}/apidocs.html
%{_defaultdocdir}/%{name}/*
%{prefix}/share/%{name}
%{_libdir}/libgphoto2.so.*
%{_libdir}/libgphoto2_port.so.*
%{_mandir}/man3/libgphoto2.3*
%{_mandir}/man3/libgphoto2_port.3*
/usr/share/hal/fdi/information/20thirdparty/10-camera-libgphoto2.fdi
%if 0%{?suse_version} >= 1120
/lib/udev/rules.d/40-libgphoto2.rules
%endif
# /usr/share/hal/fdi/information/20thirdparty/10-camera-libgphoto2-device.fdi

%files lang -f libgphoto2-all.lang

%files devel
%defattr(-,root,root)
%doc apidocs
%{prefix}/include/gphoto2
%{prefix}/bin/gphoto2-config
%{prefix}/bin/gphoto2-port-config
%{_libdir}/libgphoto2.so
%{_libdir}/libgphoto2.la
%{_libdir}/libgphoto2_port.so
%{_libdir}/libgphoto2_port.la
%{_libdir}/pkgconfig/libgphoto2.pc
%{_libdir}/pkgconfig/libgphoto2_port.pc

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%changelog
